@@ -301,7 +301,7 @@ def DesignIdentifyPrimer(args):
         print("[Target_microorganisms]", "\n ", "Input sequences:", input_seq, "/ Average length:", Average_length, "\n  ", "\n   ".join([name + " [circular]" if circular_index[name] else name for name in Sort_index]))
     else:
         print("[Target_microorganisms]", "\n ", "Input sequences:", input_seq, "/ Average length:", Average_length, "\n  ", "\n   ".join([name + " [circular]" if circular_index[name] else name for name in Sort_index[0:3]]), "\n\n    ... \n\n  ", "\n   ".join([name + " [circular]" if circular_index[name] else name for name in Sort_index[(len(Sort_index)-3):len(Sort_index)]]))
-    print("[Parameters]", "\n  ", "Probe size: {0}\n   Allowance: {1}\n   Cut_off_lower: {2}\n   Cut_off_upper: {3}\n   Interval_distance: {4}\n   Match_rate: {5}\n   CPU usage: {6}\n   Homology_calculation_chunks: {7}\n   Maximum_annealing_site_number: {8}\n   Window_size: {9}\n   Exclude_sequences_list: {10}\n   Search_mode: {11}\n   Score_calculation_mode: {12}".format(Probe_size_range_description, allowance, cut_off_lower, cut_off_upper, interval_distance, Match_rate, CPU, homology_calculation_chunks, Maximum_annealing_site_number, Window_size, "\n                           ".join([name + " [circular]" if exclude_circular_index[name] else name for name in [str(es) for es in Exclude_sequences_list.keys()]]) if len(Exclude_sequences_list) != 0 else "empty", Search_mode, Score_calculation))
+    print("[Parameters]", "\n  ", "Primer size: {0}\n   Allowance: {1}\n   Cut_off_lower: {2}\n   Cut_off_upper: {3}\n   Interval_distance: {4}\n   Match_rate: {5}\n   CPU usage: {6}\n   Homology_calculation_chunks: {7}\n   Maximum_annealing_site_number: {8}\n   Window_size: {9}\n   Exclude_sequences_list: {10}\n   Search_mode: {11}\n   Score_calculation_mode: {12}".format(Probe_size_range_description, allowance, cut_off_lower, cut_off_upper, interval_distance, Match_rate, CPU, homology_calculation_chunks, Maximum_annealing_site_number, Window_size, "\n                           ".join([name + " [circular]" if exclude_circular_index[name] else name for name in [str(es) for es in Exclude_sequences_list.keys()]]) if len(Exclude_sequences_list) != 0 else "empty", Search_mode, Score_calculation))
     if size_range == 0:
         if len(Exclude_sequences_list) == 0:
             Total_procedure = input_seq + 12
@@ -402,7 +402,7 @@ def DesignIdentifyPrimer(args):
             Score = [fragment_size_distance(sequence_summary.iloc[i], sum = False) / (Fragment_number[i] - min(Fragment_number) + 1) for i in tqdm(range(sequence_summary.shape[0]), total = sequence_summary.shape[0], desc = "    Calculating score and sorting", leave = False, position = 1, unit = "tasks", unit_scale = True)]
             Result = Result.assign(Score = Score, Fragment_number = Fragment_number)
             Result = Result[Result['Score'] != 0]
-            Result['Score'] = Result['Score'].apply(lambda x:round(x, -2))
+            Result['Score'] = Result['Score'].apply(lambda x:round(x, -1))
             Result = Result.sort_values(['Fragment_number', 'Score'], ascending = [True, False])
         elif Score_calculation == "Sequence":
             Position_data = Position_data.assign(Flexibility = Flexibility_score)
@@ -442,7 +442,7 @@ def DesignIdentifyPrimer(args):
             value = [input_file, ", ".join(list(seq_dict.keys())), "-", "-", "-", "-", "-", "-", "-", "-", Result_output, "-", "-", "-", Score_calculation]
         else:
             value = [input_file, ", ".join(list(seq_dict.keys())), str(args.exclude_file) + "[" + str(Exclude_mode) + "]" if args.exclude_file is not None else "None", ", ".join(list(Exclude_sequences_list.keys())), Probe_size_range_description, allowance, cut_off_lower, cut_off_upper, interval_distance, Match_rate, Result_output, Search_mode, Window_size, Maximum_annealing_site_number, Score_calculation]
-        args = ["Input_file_name", "Target", "Exclude_file_name", "Exclude_target", "Probe_size_range_description", "allowance", "cut_off_lower", "cut_off_upper", "Interval_distance", "Match_rate", "Result_output", "Search_mode", "Window_size", "Maximum_annealing_site_number", "Score_calculation_mode"]
+        args = ["Input_file_name", "Target", "Exclude_file_name", "Exclude_target", "Primer_size_range_description", "allowance", "cut_off_lower", "cut_off_upper", "Interval_distance", "Match_rate", "Result_output", "Search_mode", "Window_size", "Maximum_annealing_site_number", "Score_calculation_mode"]
         Argument_input = pd.DataFrame(value, index = [args], columns = ["Arguments"])
         Argument_input.to_csv(output_folder+'Result/'+TimeStamp+'identify_primer_set'+'/'+TimeStamp+'Summary.csv', mode = 'a', sep=',')
         Result_Output = Result.copy(deep = True)
@@ -450,6 +450,12 @@ def DesignIdentifyPrimer(args):
         Result_Output.set_index('No', append = True, inplace = True)
         Result_Output.index = Result_Output.index.rename(["Forward","Reverse", "No"])
         Result_Output.to_csv(output_folder+'Result/'+TimeStamp+'identify_primer_set'+'/'+TimeStamp+'Summary.csv', mode = 'a', sep =',')
+        if Result_Output.empty:
+            progress_bar.update(2)
+            Message = pd.DataFrame(["No primer set that can be used for identification was generated."])
+            Message.to_csv(output_folder+'Result/'+TimeStamp+'identify_primer_set'+'/'+TimeStamp+'Summary.csv', mode = 'a', sep =',', header = None, index = None)
+            print("\n No primer set that can be used for identification was generated.")
+            sys.exit()
         del Result_Output
         progress_bar.update(1)
         if Score_calculation == "Fragment":
@@ -492,8 +498,14 @@ def DesignIdentifyPrimer(args):
                     Sequence_Row_d = dict(sorted(Sequence_Row_d.items(), key = lambda x:x[1]))
                     Primer_sequence = "\n".join(['No.' + str(value) + '| Forward: ' + str(key[0]) + ', ' + 'Reverse: ' + str(key[1]) for key, value in Sequence_Row_d.items()])
                     Maximum_sequence_length = np.max([len(name) for name in Sequence_name])
-                    if Maximum_sequence_length > 40:
+                    if Maximum_sequence_length > 60:
+                        Font_size = 6
+                    elif Maximum_sequence_length > 40:
                         Font_size = 8
+                    elif Maximum_sequence_length > 20:
+                        Font_size = 10
+                    else:
+                        Font_size = 12
                     if np.logical_not(os.path.exists(output_folder + 'Result/' + TimeStamp + 'identify_primer_set/Dendrogram')):
                         os.mkdir(output_folder + 'Result/' + TimeStamp + 'identify_primer_set/Dendrogram')
                     fig = plt.figure(figsize = (12, 6,), dpi = 300)
@@ -531,8 +543,14 @@ def DesignIdentifyPrimer(args):
                     Dendrogram_data = linkage(Distance_matrix, method = "average")
                     Primer_sequence = 'No.' + str(no + 1) + '| Forward: ' + str(Result.index[no][0]) + ', ' + 'Reverse: ' + str(Result.index[no][1])
                     Maximum_sequence_length = np.max([len(name) for name in Sequence_name])
-                    if Maximum_sequence_length > 40:
+                    if Maximum_sequence_length > 60:
+                        Font_size = 6
+                    elif Maximum_sequence_length > 40:
                         Font_size = 8
+                    elif Maximum_sequence_length > 20:
+                        Font_size = 10
+                    else:
+                        Font_size = 12
                     if np.logical_not(os.path.exists(output_folder + 'Result/' + TimeStamp + 'identify_primer_set/Dendrogram')):
                         os.mkdir(output_folder + 'Result/' + TimeStamp + 'identify_primer_set/Dendrogram')
                     fig = plt.figure(figsize = (12, 6,), dpi = 300)
