@@ -506,7 +506,7 @@ class nucleotide_sequence(str):
             return Start_positions
         else:
             return None
-    def PCR_amplicon(self, forward, reverse, allowance = 0, Single_amplicon = True, Sequence_Only = True, amplicon_size_limit = 10000, Warning_ignore = False, circularDNAtemplate = False):
+    def PCR_amplicon(self, forward, reverse, allowance = 0, Single_amplicon = True, Sequence_Only = True, amplicon_size_limit = 10000, Warning_ignore = False, circularDNAtemplate = False, IgnoreLowQualityRegion = True):
         '''
         In silico PCR.
 
@@ -538,6 +538,13 @@ class nucleotide_sequence(str):
         Original_template_length = len(str(template))
         if circularDNAtemplate:
             template = str(template) + str(template)[0:int(np.min([amplicon_size_limit, Original_template_length * 0.1])):]
+        if IgnoreLowQualityRegion:
+            IGNORE = math.ceil(np.max([np.min([len(str(forward)), len(str(reverse))]) - allowance, 2]))
+            IGNORE = r"".join(["N" for n in range(IGNORE)]) + r'+'
+            IGNORE = re.findall(IGNORE, template)
+            IGNORE.sort(reverse = True)
+            for igr in IGNORE:
+                template = re.sub(igr, igr.replace("N", "X"), template)
         template = nucleotide_sequence(template)
         PCR_amplicon = None
         if type(forward) is not nucleotide_sequence:
