@@ -217,15 +217,19 @@ def fragment_size_distance(array, sum = False):
                 arr1_i_arr2.append((np.array(darr1)[np.any(distance == np.min(distance), axis = 0)][0] - np.array(darr2)[np.any(distance == np.min(distance), axis = 1)][0]))
                 darr1.remove(np.array(darr1)[np.any(distance == np.min(distance), axis = 0)][0])
                 darr2.remove(np.array(darr2)[np.any(distance == np.min(distance), axis = 1)][0])
-            Result.append(np.sum(np.array(arr1_i_arr2) ** 2) ** (1/2) + np.sum(darr1))
-        elif len(darr1) < len(darr2):
+            REMAINDER = [np.abs(np.array(list(arr1) + list(arr2)) - b) for b in darr1]
+            REMAINDER = np.sum([min([rem for rem in remain if rem != 0], default = 0) for remain in REMAINDER])
+            Result.append(np.sum(np.array(arr1_i_arr2) ** 2) ** (1/2) + REMAINDER)
+        elif len(arr1) < len(arr2):
             arr2_i_arr1 = []
             while len(darr1) > 0:
                 distance = np.abs(np.array([np.array(darr2) - b for b in darr1]))
                 arr2_i_arr1.append((np.array(darr2)[np.any(distance == np.min(distance), axis = 0)][0] - np.array(darr1)[np.any(distance == np.min(distance), axis = 1)][0]))
                 darr2.remove(np.array(darr2)[np.any(distance == np.min(distance), axis = 0)][0])
                 darr1.remove(np.array(darr1)[np.any(distance == np.min(distance), axis = 1)][0])
-            Result.append(np.sum(np.array(arr2_i_arr1) ** 2) ** (1/2) + np.sum(darr2))
+            REMAINDER = [np.abs(np.array(list(arr1) + list(arr2)) - b) for b in darr2]
+            REMAINDER = np.sum([min([rem for rem in remain if rem != 0], default = 0) for remain in REMAINDER])
+            Result.append(np.sum(np.array(arr2_i_arr1) ** 2) ** (1/2) + REMAINDER)
         else:
             arr1_arr2 = []
             while len(darr2) > 0:
@@ -234,10 +238,12 @@ def fragment_size_distance(array, sum = False):
                 darr1.remove(np.array(darr1)[np.any(distance == np.min(distance), axis = 0)][0])
                 darr2.remove(np.array(darr2)[np.any(distance == np.min(distance), axis = 1)][0])
             Result.append(np.sum(np.array(arr1_arr2) ** 2) ** (1/2))
-    if sum:
-        return np.sum(Result) / len(array)
+    if len(Result) == 0:
+        return 0
+    elif sum:
+        return np.sum(Result) / len(Result)
     else:
-        return np.prod(Result) ** (1/len(array))
+        return np.prod(Result) ** (1/len(Result))
 
 def array_diff(arr1, arr2, lower, upper, logical = False, separation_key = []):
     '''
